/* cc-theme-info.h
 *
 * Copyright 2019 Georges Basile Stavracas Neto <georges.stavracas@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <glib.h>
#include <glib-object.h>

G_BEGIN_DECLS

#define CC_TYPE_THEME_INFO (cc_theme_info_get_type ())
G_DECLARE_FINAL_TYPE (CcThemeInfo, cc_theme_info, CC, THEME_INFO, GObject)

typedef enum
{
    CC_THEME_DESKTOP,   //usr/share/themes， it is a style theme, maybe it has many color themes
    CC_THEME_COLOR,     //usr/share/themes, colors for a style theme
    CC_THEME_ICONS,     //usr/share/icons
    CC_THEME_CURSOR,    //cursor theme in icons
} CcThemeType;

//index.theme group name
#define DESKTOP_ENTRY_GROUP "Desktop Entry"
#define DESKTOP_THEME_GROUP "X Found Metatheme"
#define ICON_THEME_GROUP    "Icon Theme"

/* 
 * type value in index.theme file 
 */
#define DESKTOP_THEME_TYPE      "X-Found-Metatheme"
#define COLOR_THEME_TYPE        "X-Found-Colortheme"
#define ICON_THEME_TYPE         "X-Found-Icontheme"
#define CURSOR_THEME_TYPE       "X-Found-Cursortheme"

CcThemeInfo *
cc_theme_info_new (CcThemeType theme_type);
GList *
cc_theme_info_get_all (CcThemeInfo *self);
GKeyFile *
cc_theme_info_get_key_file (CcThemeInfo *self, gchar *name);
gchar *
cc_theme_info_get_display_name (CcThemeInfo *self, gchar *name);
gchar *
cc_theme_info_get_comment (CcThemeInfo *self, gchar *name);
gboolean 
cc_theme_info_is_valid_theme (CcThemeInfo *self, gchar *name);

G_END_DECLS
